@@ -33,14 +33,13 @@ sub start_child {
     my $pid = fork();
     die $! unless defined $pid;
     unless ($pid) {
-        exec $^X, '-Iblib/lib', '-Ilib', @$cmd or die $!;
+        exec 'perl', '-Iblib/lib', '-Ilib', @$cmd or die $!;
     }
     $pid;
 }
 
 package Test::GearServer;
 use List::Util qw(first);
-use File::Basename 'dirname';
 
 my $requested_port = 8999;
 
@@ -49,7 +48,6 @@ sub new {
     my $port = GearTestLib::free_port(++$requested_port);
 
     my @loc = ("$FindBin::Bin/../../../../server/gearmand",  # using svn
-               dirname($^X) . '/gearmand',     # local installs (e.g. perlbrew)
                '/usr/bin/gearmand',            # where some distros might put it
                '/usr/sbin/gearmand',           # where other distros might put it
                );
